#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import aiohttp
import asyncio
import async_timeout
import os


async def download(session, url):
    filename = os.path.basename(url)
    print(f'Starting downloading {filename}')

    with async_timeout.timeout(10):
        async with session.get(url) as response:
            with open(filename, 'wb') as fout:
                while True:
                    chunk = await response.content.read(1024)
                    if not chunk:
                        break
                    fout.write(chunk)

    print(f'Finished downloading {filename}')


async def main():
    urls = [f'https://d3s.mff.cuni.cz/files/teaching/nprg065/2019/python-lecture-0{x}.pdf' for x in range(1, 4)]
    async with aiohttp.ClientSession() as session:
        tasks = [download(session, url) for url in urls]
        await asyncio.wait(tasks)


loop = asyncio.get_event_loop()
loop.run_until_complete(main())
loop.close()
